@@ -1,12 +1,19 @@
 #' Validates and Optionally Repairs Sex Coding in a Pedigree Dataframe
 #'
 #' This function performs two main tasks:
-#' 1. Optionally recodes the 'sex' variable based on a given code for males.
-#' 2. Optionally repairs the sex coding based on a specified logic.
+#' 1. Optionally recodes the 'sex' variable based on given codes for males and females.
+#' 2. Optionally repairs the sex coding based on specified logic, facilitating the accurate construction of genetic pedigrees.
+#'
+#' @details This function uses the terms 'male' and 'female' in a biological context, based on chromosomes and other biologically-based characteristics relevant to genetic studies.
+#' This usage is not intended to negate the personal gender identity of any individual.
+#'
+#' We recognize the importance of using language and methodologies that affirm and respect all gender identities.  While this function focuses on chromosomal information necessary for constructing genetic pedigrees, we affirm that gender is a spectrum, encompassing a wide range of identities beyond the binary.
+#' The developers of this package express unequivocal support for folx in the transgender and LGBTQ+ communities. We respect the complexity of gender identity and acknowledge the distinction between the biological aspect of sex used for genetic analysis (genotype) and the broader, richer concept of gender identity (phenotype).
+#'
 #'
 #' @param ped A dataframe representing the pedigree data with a 'sex' column.
-#' @param code_male The current code used to represent males in the 'sex' column. At least one is needed.
-#' @param code_female The current code used to represent females in the 'sex' column. If both male and female are NULL, no recoding is performed.
+#' @param code_male The current code used to represent males in the 'sex' column.
+#' @param code_female The current code used to represent females in the 'sex' column. If both are NULL, no recoding is performed.
 #' @param verbose A logical flag indicating whether to print progress and validation messages to the console.
 #' @param repair A logical flag indicating whether to attempt repairs on the sex coding.
 #'
@@ -22,17 +29,17 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
   # Standardize column names in the input dataframe
   ped <- standardizeColnames(ped)
 
-  # TO DO bypass the rest of the function if recode_only is TRUE
+  # TO DO: bypass the rest of the function if recode_only is TRUE
 
   # Initialize a list to store validation results
   validation_results <- list()
 
 
   if (verbose) {
-    cat("Step 1: Checking how many genders...\n")
+    cat("Step 1: Checking how many sexes/genders...\n")
   }
-  # check how many genders
 
+  # Check unique values in 'sex'
   validation_results$sex_unique <- unique(ped$sex)
   validation_results$sex_length <- length(unique(ped$sex))
   if (verbose) {
@@ -41,8 +48,7 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
       paste0(validation_results$sex_unique)
     ))
   }
-  # are there multiple genders in the list of dads and moms?
-
+  # Are there multiple sexes/genders in the list of dads and moms?
 
   table_sex_dad <- sort(table(ped$sex[ped$ID %in% ped$dadID]), decreasing = TRUE)
   table_sex_mom <- sort(table(ped$sex[ped$ID %in% ped$momID]), decreasing = TRUE)
@@ -53,7 +59,7 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
   validation_results$most_frequent_sex_dad <- validation_results$all_sex_dad[1]
   validation_results$most_frequent_sex_mom <- validation_results$all_sex_mom[1]
 
-  # list ids for dads that are female, moms that are male
+  # List ids for dads that are female, moms that are male
   if (length(validation_results$all_sex_dad) > 1) {
     df_dads <- ped[ped$ID %in% ped$dadID, ]
     validation_results$ID_female_dads <- df_dads$ID[df_dads$sex != validation_results$most_frequent_sex_dad]
@@ -63,7 +69,7 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
   if (length(validation_results$all_sex_mom) > 1) {
     df_moms <- ped[ped$ID %in% ped$momID, ]
     validation_results$ID_male_moms <- df_moms$ID[df_moms$sex != validation_results$most_frequent_sex_mom]
-    validation_results$ID_child_male_moms <- ped$ID[ped$momID %in% validation_results$ID_female_moms]
+    validation_results$ID_child_male_moms <- ped$ID[ped$momID %in% validation_results$ID_male_moms]
     remove(df_moms)
   }
 
@@ -77,9 +83,7 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
     original_ped <- ped
 
     if (validation_results$sex_length == 2) {
-      # if length of all_sex_dad >1, then recode all the dads to the most frequent male value
-
-
+      # Recode all dads to the most frequent male value
       ped <- recodeSex(ped, code_male = validation_results$most_frequent_sex_dad)
       # Count and record the change
       num_changes <- sum(original_ped$sex != ped$sex)
@@ -89,14 +93,13 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
         validation_results$most_frequent_sex_dad, num_changes
       )
     }
-    # Update the pedigree dataframe after repair
-    repaired_ped <- ped
+    # Return the repaired pedigree dataframe
 
     if (verbose) {
       cat("Changes Made:\n")
       print(changes)
     }
-    return(repaired_ped)
+    return(ped)
   } else {
     if (verbose) {
       cat("Checks Made:\n")
@@ -115,6 +118,7 @@ checkSex <- function(ped, code_male = NULL, code_female = NULL, verbose = FALSE,
 #'
 #' @inheritParams checkSex
 #' @inheritParams plotPedigree
+#' @inherit checkSex details
 #' @return A modified version of the input data.frame \code{ped}, containing an additional or modified 'sex_recode' column where the 'sex' values are recoded according to \code{code_male}. NA values in the 'sex' column are preserved.
 #' @examples
 #' \dontrun{
@@ -130,13 +134,20 @@ repairSex <- function(ped, verbose = FALSE, code_male = NULL) {
 
 #' Recodes Sex Variable in a Pedigree Dataframe
 #'
-#' This function serves as a wrapper around `checkSex` to specifically handle
-#' the recoding of the 'sex' variable in a pedigree dataframe.
+#' This function serves as is primarily used internally, by plotting functions etc.
+#' It sets the `repair` flag to TRUE automatically and forwards any additional parameters to `checkSex`.
+#'
 #' @inheritParams checkSex
 #' @inheritParams plotPedigree
+#' @param code_na The current value used for missing values.
+#' @param recode_na The value to use for missing values. Default is NA_character_
+#' @param recode_male The value to use for males. Default is "M"
+#' @param recode_female The value to use for females. Default is "F"
+#' @inherit checkSex details
 #' @return A modified version of the input data.frame \code{ped}, containing an additional or modified 'sex_recode' column where the 'sex' values are recoded according to \code{code_male}. NA values in the 'sex' column are preserved.
-#' @keywords internal
+#' @export
 #' @seealso \code{\link{plotPedigree}}
+#' @export
 recodeSex <- function(
     ped, verbose = FALSE, code_male = NULL, code_na = NULL, code_female = NULL,
     recode_male = "M", recode_female = "F", recode_na = NA_character_) {
@@ -150,7 +161,7 @@ recodeSex <- function(
     ped$sex_recode <- recode_na
     ped$sex_recode[ped$sex == code_female] <- recode_female
     ped$sex_recode[ped$sex == code_male] <- recode_male
-    # overwriting temp recode variable
+    # Overwriting temp recode variable
     ped$sex <- ped$sex_recode
     ped$sex_recode <- NULL
   } else if (!is.null(code_male) & is.null(code_female)) {
@@ -158,7 +169,7 @@ recodeSex <- function(
     ped$sex_recode <- recode_na
     ped$sex_recode[ped$sex != code_male & !is.na(ped$sex)] <- recode_female
     ped$sex_recode[ped$sex == code_male] <- recode_male
-    # overwriting temp recode variable
+    # Overwriting temp recode variable
     ped$sex <- ped$sex_recode
     ped$sex_recode <- NULL
   } else if (is.null(code_male) & !is.null(code_female)) {
@@ -166,12 +177,12 @@ recodeSex <- function(
     ped$sex_recode <- recode_na
     ped$sex_recode[ped$sex != code_female & !is.na(ped$sex)] <- recode_male
     ped$sex_recode[ped$sex == code_female] <- recode_female
-    # overwriting temp recode variable
+    # Overwriting temp recode variable
     ped$sex <- ped$sex_recode
     ped$sex_recode <- NULL
   } else {
     if (verbose) {
-      warning(" both code male and code female are empty. No recoding was done.")
+      warning("Both code male and code female are empty. No recoding was done.")
     }
   }
   return(ped)
